<?php return array(
	'a11y/index.js' => array(
		'dependencies' => array(
			
		),
		'version' => 'f62f48906198ea8abc60'
	),
	'abilities/index.js' => array(
		'dependencies' => array(
			'wp-data',
			'wp-i18n'
		),
		'version' => '104b6117f4f3d5b94cc3'
	),
	'block-editor/utils/fit-text-frontend.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => 'f465b12ad4eba72e96bb'
	),
	'block-library/accordion/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => '2bfb90e7aee6b5300a7c'
	),
	'block-library/file/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => 'a9114a756e418400594c'
	),
	'block-library/form/view.js' => array(
		'dependencies' => array(
			
		),
		'version' => '5542f8ad251fe43ef09e'
	),
	'block-library/image/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => '25ee935fd6c67371d0f3'
	),
	'block-library/navigation/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => '1bf28ded04f9f188bdcb'
	),
	'block-library/playlist/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => 'e921883a3f8a7b1ead70'
	),
	'block-library/query/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			),
			array(
				'id' => '@wordpress/interactivity-router',
				'import' => 'dynamic'
			)
		),
		'version' => '7a4ec5bfb61a7137cf4b'
	),
	'block-library/search/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => '38bd0e230eaffa354d2a'
	),
	'block-library/tabs/view.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => 'cc1a34b1bee3c2e17bc4'
	),
	'boot/index.js' => array(
		'dependencies' => array(
			'react',
			'react-dom',
			'react-jsx-runtime',
			'wp-components',
			'wp-compose',
			'wp-core-data',
			'wp-data',
			'wp-editor',
			'wp-element',
			'wp-html-entities',
			'wp-i18n',
			'wp-keyboard-shortcuts',
			'wp-keycodes',
			'wp-notices',
			'wp-primitives',
			'wp-private-apis',
			'wp-theme'
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/a11y',
				'import' => 'static'
			),
			array(
				'id' => '@wordpress/lazy-editor',
				'import' => 'dynamic'
			),
			array(
				'id' => '@wordpress/route',
				'import' => 'static'
			)
		),
		'version' => '97d6c844a12f1615212a'
	),
	'connectors/index.js' => array(
		'dependencies' => array(
			'react-jsx-runtime',
			'wp-components',
			'wp-data',
			'wp-element',
			'wp-i18n',
			'wp-private-apis'
		),
		'version' => '8aa4346de9f4f9cbfaef'
	),
	'content-types/index.js' => array(
		'dependencies' => array(
			'react',
			'react-dom',
			'react-jsx-runtime',
			'wp-components',
			'wp-compose',
			'wp-core-data',
			'wp-data',
			'wp-date',
			'wp-deprecated',
			'wp-element',
			'wp-i18n',
			'wp-is-shallow-equal',
			'wp-keycodes',
			'wp-notices',
			'wp-preferences',
			'wp-primitives',
			'wp-private-apis',
			'wp-rich-text',
			'wp-theme',
			'wp-url',
			'wp-warning'
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/a11y',
				'import' => 'static'
			),
			array(
				'id' => '@wordpress/route',
				'import' => 'static'
			)
		),
		'version' => '06bbdee380f4cf86dff0'
	),
	'core-abilities/index.js' => array(
		'dependencies' => array(
			'wp-api-fetch',
			'wp-url'
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/abilities',
				'import' => 'static'
			)
		),
		'version' => '012760fd849397dd0031'
	),
	'dashboard-init/index.js' => array(
		'dependencies' => array(
			'wp-core-data',
			'wp-data',
			'wp-i18n'
		),
		'version' => 'dfe923ac4bd0bd01b9aa'
	),
	'edit-site-init/index.js' => array(
		'dependencies' => array(
			'react-jsx-runtime',
			'wp-data',
			'wp-element',
			'wp-primitives'
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/boot',
				'import' => 'static'
			)
		),
		'version' => 'e2f82d3d1c3179d25626'
	),
	'interactivity/index.js' => array(
		'dependencies' => array(
			
		),
		'version' => 'efaa5193bbad9c60ffd1'
	),
	'interactivity-router/full-page.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/interactivity-router',
				'import' => 'dynamic'
			)
		),
		'version' => '5c07cd7a12ae073c5241'
	),
	'interactivity-router/index.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/a11y',
				'import' => 'dynamic'
			),
			array(
				'id' => '@wordpress/interactivity',
				'import' => 'static'
			)
		),
		'version' => 'a6e90b8896f83fb1b5dd'
	),
	'latex-to-mathml/index.js' => array(
		'dependencies' => array(
			
		),
		'version' => '662cb0e7f68d2a21cd68'
	),
	'latex-to-mathml/loader.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/latex-to-mathml',
				'import' => 'dynamic'
			)
		),
		'version' => '4f37456af539bd3d2351'
	),
	'lazy-editor/index.js' => array(
		'dependencies' => array(
			'react-jsx-runtime',
			'wp-block-editor',
			'wp-blocks',
			'wp-components',
			'wp-core-data',
			'wp-data',
			'wp-editor',
			'wp-element',
			'wp-i18n',
			'wp-private-apis',
			'wp-style-engine'
		),
		'version' => 'f947bd8281443624c0d0'
	),
	'route/index.js' => array(
		'dependencies' => array(
			'react',
			'react-dom',
			'react-jsx-runtime',
			'wp-private-apis'
		),
		'version' => 'ef851c0f4dda0d1dd359'
	),
	'video-conversion/loader.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/video-conversion/worker',
				'import' => 'dynamic'
			)
		),
		'version' => '81a2ac6d5619086278fd'
	),
	'video-conversion/worker.js' => array(
		'dependencies' => array(
			
		),
		'version' => '4d3627c45251ceb4f9a2'
	),
	'vips/loader.js' => array(
		'dependencies' => array(
			
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/vips/worker',
				'import' => 'dynamic'
			)
		),
		'version' => '07c9acb45d3e5d81829a'
	),
	'vips/worker.js' => array(
		'dependencies' => array(
			
		),
		'version' => '685442d334b2d3e70832'
	),
	'workflow/index.js' => array(
		'dependencies' => array(
			'react',
			'react-dom',
			'react-jsx-runtime',
			'wp-components',
			'wp-data',
			'wp-element',
			'wp-i18n',
			'wp-keyboard-shortcuts',
			'wp-primitives',
			'wp-private-apis'
		),
		'module_dependencies' => array(
			array(
				'id' => '@wordpress/abilities',
				'import' => 'static'
			),
			array(
				'id' => '@wordpress/core-abilities',
				'import' => 'dynamic'
			)
		),
		'version' => '9e09ede3195f2f51bc49'
	)
);